==> org.eclipse.papyrus.infra.services.validation.source_1.1.3.201511250900.jar: org/eclipse/papyrus/infra/services/validation/commands/ValidateDelMarkersFromModelCommand.java <==
/*****************************************************************************
 * Copyright (c) 2010, 2013 CEA LIST.
 *
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Ansgar Radermacher (CEA LIST) ansgar.radermacher@cea.fr - Initial API and implementation
 *  Christian W. Damus (CEA) - refactor for non-workspace abstraction of problem markers (CDO)
 *
 *****************************************************************************/

package org.eclipse.papyrus.infra.services.validation.commands;

import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.resources.IMarker;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.transaction.util.TransactionUtil;
import org.eclipse.gmf.runtime.common.core.command.CommandResult;
import org.eclipse.papyrus.infra.services.markerlistener.providers.IMarkerProvider;
import org.eclipse.papyrus.infra.services.markerlistener.util.MarkerListenerUtils;
import org.eclipse.papyrus.infra.services.validation.IPapyrusDiagnostician;
import org.eclipse.papyrus.infra.services.validation.Messages;


public class ValidateDelMarkersFromModelCommand extends AbstractValidateCommand {

	public ValidateDelMarkersFromModelCommand(EObject selectedElement, IPapyrusDiagnostician diagnostician) {
		super(Messages.ValidateDelMarkersFromModelCommand_DeleteMarkersFromModel, TransactionUtil.getEditingDomain(selectedElement), selectedElement, diagnostician);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	protected CommandResult doExecuteWithResult(IProgressMonitor monitor, IAdaptable info) throws ExecutionException {
		Resource resource = getValidationResource();
		if (resource != null) {
			try {
				for (IMarkerProvider provider : MarkerListenerUtils.getMarkerProviders(getValidationResource())) {
					provider.deleteMarkers(resource, monitor, IMarker.PROBLEM, true);
				}
			} catch (CoreException e) {
				throw new ExecutionException(Messages.ValidateDelMarkersFromModelCommand_FailedToDeleteMarkers, e);
			}
		}
		return null;
	}
}

==> org.eclipse.papyrus.infra.services.validation.source_3.0.0.201805210649.jar: org/eclipse/papyrus/infra/services/validation/commands/ValidateDelMarkersFromModelCommand.java <==
/*****************************************************************************
 * Copyright (c) 2010, 2013 CEA LIST.
 *
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Ansgar Radermacher (CEA LIST) ansgar.radermacher@cea.fr - Initial API and implementation
 *  Christian W. Damus (CEA) - refactor for non-workspace abstraction of problem markers (CDO)
 *
 *****************************************************************************/

package org.eclipse.papyrus.infra.services.validation.commands;

import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.resources.IMarker;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.transaction.util.TransactionUtil;
import org.eclipse.gmf.runtime.common.core.command.CommandResult;
import org.eclipse.papyrus.infra.services.markerlistener.providers.IMarkerProvider;
import org.eclipse.papyrus.infra.services.markerlistener.util.MarkerListenerUtils;
import org.eclipse.papyrus.infra.services.validation.IPapyrusDiagnostician;
import org.eclipse.papyrus.infra.services.validation.Messages;


public class ValidateDelMarkersFromModelCommand extends AbstractValidateCommand {

	/**
	 * Constructor with EcoreDiagnostician
	 *
	 * @param selectedElement
	 *            an element of the model from which to remove markers
	 */
	public ValidateDelMarkersFromModelCommand(EObject selectedElement) {
		this(selectedElement, null);
	}
	
	/**
	 * Constructor
	 *
	 * @param selectedElement
	 *            an element of the model from which to remove markers
	 * @param diagnostician
	 *            the diagnostician (e.g. EcoreDiagnostician)
	 */
	public ValidateDelMarkersFromModelCommand(EObject selectedElement, IPapyrusDiagnostician diagnostician) {
		super(Messages.ValidateDelMarkersFromModelCommand_DeleteMarkersFromModel, TransactionUtil.getEditingDomain(selectedElement), selectedElement, diagnostician);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	protected CommandResult doExecuteWithResult(IProgressMonitor monitor, IAdaptable info) throws ExecutionException {
		Resource resource = getValidationResource();
		if (resource != null) {
			try {
				for (IMarkerProvider provider : MarkerListenerUtils.getMarkerProviders(getValidationResource())) {
					provider.deleteMarkers(resource, monitor, IMarker.PROBLEM, true);
				}
			} catch (CoreException e) {
				throw new ExecutionException(Messages.ValidateDelMarkersFromModelCommand_FailedToDeleteMarkers, e);
			}
		}
		return null;
	}
}
